==> digitalhub-0.10.1.tar.gz: digitalhub-0.10.1/digitalhub/stores/data/sql/configurator.py <==
from __future__ import annotations

from digitalhub.stores.configurator.configurator import configurator
from digitalhub.stores.configurator.enums import CredsOrigin
from digitalhub.stores.data.sql.enums import SqlStoreEnv
from digitalhub.utils.exceptions import StoreError


class SqlStoreConfigurator:
    """
    Configure the store by getting the credentials from user
    provided config or from environment.
    """

    variables = [SqlStoreEnv.USERNAME, SqlStoreEnv.PASSWORD, SqlStoreEnv.HOST, SqlStoreEnv.PORT, SqlStoreEnv.DATABASE]

    def __init__(self, config: dict | None = None) -> None:
        self.configure(config)

    ##############################
    # Configuration methods
    ##############################

    def configure(self, config: dict | None = None) -> None:
        """
        Configure the store by getting the credentials from user
        provided config or from environment.

        Parameters
        ----------
        config : dict
            Configuration dictionary.

        Returns
        -------
        None
        """
        self._get_env_config()

    def get_sql_conn_string(self, origin: str) -> str:
        """
        Get the connection string from environment variables.

        Parameters
        ----------
        origin : str
            The origin of the credentials.

        Returns
        -------
        str
            The connection string.
        """
        if origin == CredsOrigin.ENV.value:
            creds = self._get_env_config()
        elif origin == CredsOrigin.FILE.value:
            creds = self._get_file_config()
        else:
            raise StoreError(f"Unknown origin: {origin}")

        user = creds[SqlStoreEnv.USERNAME.value]
        password = creds[SqlStoreEnv.PASSWORD.value]
        host = creds[SqlStoreEnv.HOST.value]
        port = creds[SqlStoreEnv.PORT.value]
        database = creds[SqlStoreEnv.DATABASE.value]
        return f"postgresql://{user}:{password}@{host}:{port}/{database}"

    def _get_env_config(self) -> dict:
        """
        Get the store configuration from environment variables.

        Returns
        -------
        dict
            The credentials.
        """
        credentials = {var.value: configurator.load_from_env(var.value) for var in self.variables}
        self._set_credentials(credentials)
        return credentials

    def _get_file_config(self) -> dict:
        """
        Get the store configuration from file.

        Returns
        -------
        dict
            The credentials.
        """
        credentials = {var.value: configurator.load_from_file(var.value) for var in self.variables}
        self._set_credentials(credentials)
        return credentials

    def _check_credentials(self, credentials: dict) -> None:
        """
        Check for missing credentials.

        Parameters
        ----------
        credentials : dict
            The credentials.

        Returns
        -------
        None
        """
        missing_vars = [key for key, value in credentials.items() if value is None and key in self.required_vars]
        if missing_vars:
            raise StoreError(f"Missing credentials for SQL store: {', '.join(missing_vars)}")

    def _set_credentials(self, credentials: dict) -> None:
        """
        Set the store credentials into the configurator.

        Parameters
        ----------
        credentials : dict
            The credentials.

        Returns
        -------
        None
        """
        # Set credentials
        for key, value in credentials.items():
            configurator.set_credential(key, value)

==> digitalhub-0.11.0b0.tar.gz: digitalhub-0.11.0b0/digitalhub/stores/data/sql/configurator.py <==
from __future__ import annotations

from digitalhub.stores.configurator.configurator import configurator
from digitalhub.stores.configurator.enums import CredsOrigin
from digitalhub.stores.data.sql.enums import SqlStoreEnv
from digitalhub.utils.exceptions import StoreError


class SqlStoreConfigurator:
    """
    Configure the store by getting the credentials from user
    provided config or from environment.
    """

    required_vars = [
        SqlStoreEnv.USERNAME,
        SqlStoreEnv.PASSWORD,
        SqlStoreEnv.HOST,
        SqlStoreEnv.PORT,
        SqlStoreEnv.DATABASE,
    ]
    project_vars = [
        SqlStoreEnv.DATABASE,
    ]

    def __init__(self, config: dict) -> None:
        self.config = self.configure(config)

    ##############################
    # Configuration methods
    ##############################

    def configure(self, config: dict) -> dict:
        """
        Configure the store by getting vars from project.

        Parameters
        ----------
        config : dict
            Configuration dictionary.

        Returns
        -------
        dict
            Configuration dictionary.
        """
        return {k: v for k, v in config.items() if k in self.project_vars}

    def get_sql_conn_string(self, origin: str) -> str:
        """
        Get the connection string from environment variables.

        Parameters
        ----------
        origin : str
            The origin of the credentials.

        Returns
        -------
        str
            The connection string.
        """
        if origin == CredsOrigin.ENV.value:
            creds = self._get_env_config()
        elif origin == CredsOrigin.FILE.value:
            creds = self._get_file_config()
        else:
            raise StoreError(f"Unknown origin: {origin}")

        user = creds[SqlStoreEnv.USERNAME.value]
        password = creds[SqlStoreEnv.PASSWORD.value]
        host = creds[SqlStoreEnv.HOST.value]
        port = creds[SqlStoreEnv.PORT.value]
        database = creds[SqlStoreEnv.DATABASE.value]
        return f"postgresql://{user}:{password}@{host}:{port}/{database}"

    def _get_env_config(self) -> dict:
        """
        Get the store configuration from environment variables.

        Returns
        -------
        dict
            The credentials.
        """
        credentials = {var.value: configurator.load_from_env(var.value) for var in self.required_vars}
        self._set_credentials(credentials)
        return credentials

    def _get_file_config(self) -> dict:
        """
        Get the store configuration from file.

        Returns
        -------
        dict
            The credentials.
        """
        credentials = {var.value: configurator.load_from_file(var.value) for var in self.required_vars}
        self._set_credentials(credentials)
        return credentials

    def _check_credentials(self, credentials: dict) -> None:
        """
        Check for missing credentials.

        Parameters
        ----------
        credentials : dict
            The credentials.

        Returns
        -------
        None
        """
        missing_vars = [key for key, value in credentials.items() if value is None and key in self.required_vars]
        if missing_vars:
            raise StoreError(f"Missing credentials for SQL store: {', '.join(missing_vars)}")

    def _set_credentials(self, credentials: dict) -> None:
        """
        Set the store credentials into the configurator.

        Parameters
        ----------
        credentials : dict
            The credentials.

        Returns
        -------
        None
        """
        # Set credentials
        for key, value in credentials.items():
            configurator.set_credential(key, value)
